# History

## 0.1.1

* Add better pretrained models.
* Improve support for non CUDA devices.

## 0.1.0 - First release to PyPi

* SteganoGAN class which can be fitted, saved, loaded and used to encode and decode messages.
* Basic command line interface that allow using pretrained models.
* Basic and Dense pretrained models for demo purposes.
